@@ -2,15 +2,13 @@
 
 Regexp::Common::time - Date and time regexps.
 
-=head1 VERSION
-
-This is version 0.05 of Regexp::Common::time, Nov 20, 2013.
-
 =cut
 
 use strict;
+use warnings;
+
 package Regexp::Common::time;
-$Regexp::Common::time::VERSION = '0.05';
+$Regexp::Common::time::VERSION = '0.07';
 use Regexp::Common qw(pattern);
 use POSIX;
 
